@@ -1,4 +1,4 @@
-""" testing for stochastic dominance """
+""" PySDTest: A Pyhton Package for Stochastic Dominance Tests """
 
 from pysdtest.pysdtest import test_sd, test_sd_SR, test_sd_contact, test_sd_NDM
 from pysdtest.Test_Stat_Functions import operator, CDF, set_grid
